<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="he">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN מופעל</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN מופסק</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>השכילה של Caps Lock מופעלת</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>השכילה של Caps Lock מופסקת</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>השכילה של판 מספרי מופעלת</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>השכילה של판 מספרי מופסקת</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>השכילה של판 משטח מגע מופעלת</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>השכילה של판 משטח מגע מופסקת</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>השכילה של판 משטח מגע: הופך</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn: הופך</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>מצב מטוס מופעל</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>מצב מטוס מופסק</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>הופך לכוח 균ד</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>הופך למכות שמירה</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>הופך לpering מוגבר</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>הופך לתמונות חלון מופעל</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>הופך לתמונות חלון מופסק</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>נכשל להופך לתמונות חלון</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>